@@ -418,7 +418,9 @@ class Object(object):
         - Right after a room starts for the first time after the object
           was added to it, if and only if the object was added to the
           room while it was not the current room.  In this case, this
-          event is called after the respective room start event.
+          event is called for each appropriate object after the
+          respective room start event or room resume event, in the same
+          order that the objects were added to the room.
         """
         pass
 
@@ -562,37 +564,49 @@ class Object(object):
         The default behavior of this method is the following code::
 
             if delta_mult:
-                vf = self.xvelocity + self.xacceleration * delta_mult
-                dc = min(abs(vf), abs(self.xdeceleration))
-                a = self.xacceleration - math.copysign(dc, vf)
-                self.move_x(self.xvelocity * delta_mult +
-                            0.5 * a * (delta_mult ** 2))
-                self.xvelocity += a * delta_mult
+                vi = self.xvelocity
+                vf = vi + self.xacceleration * delta_mult
+                dc = abs(self.xdeceleration) * delta_mult
+                if abs(vf) > dc:
+                    vf -= math.copysign(dc, vf)
+                else:
+                    vf = 0
+                self.xvelocity = vf
+                self.move_x(((vi + vf) / 2) * delta_mult)
 
-                vf = self.yvelocity + self.yacceleration * delta_mult
-                dc = min(abs(vf), abs(self.ydeceleration))
-                a = self.yacceleration - math.copysign(dc, vf)
-                self.move_y(self.yvelocity * delta_mult +
-                            0.5 * a * (delta_mult ** 2))
-                self.yvelocity += a * delta_mult
+                vi = self.yvelocity
+                vf = vi + self.yacceleration * delta_mult
+                dc = abs(self.ydeceleration) * delta_mult
+                if abs(vf) > dc:
+                    vf -= math.copysign(dc, vf)
+                else:
+                    vf = 0
+                self.yvelocity = vf
+                self.move_y(((vi + vf) / 2) * delta_mult)
 
         See the documentation for :meth:`sge.Game.event_step` for more
         information.
         """
         if delta_mult:
-            vf = self.xvelocity + self.xacceleration * delta_mult
-            dc = min(abs(vf), abs(self.xdeceleration))
-            a = self.xacceleration - math.copysign(dc, vf)
-            self.move_x(self.xvelocity * delta_mult +
-                        0.5 * a * (delta_mult ** 2))
-            self.xvelocity += a * delta_mult
+            vi = self.xvelocity
+            vf = vi + self.xacceleration * delta_mult
+            dc = abs(self.xdeceleration) * delta_mult
+            if abs(vf) > dc:
+                vf -= math.copysign(dc, vf)
+            else:
+                vf = 0
+            self.xvelocity = vf
+            self.move_x(((vi + vf) / 2) * delta_mult)
 
-            vf = self.yvelocity + self.yacceleration * delta_mult
-            dc = min(abs(vf), abs(self.ydeceleration))
-            a = self.yacceleration - math.copysign(dc, vf)
-            self.move_y(self.yvelocity * delta_mult +
-                        0.5 * a * (delta_mult ** 2))
-            self.yvelocity += a * delta_mult
+            vi = self.yvelocity
+            vf = vi + self.yacceleration * delta_mult
+            dc = abs(self.ydeceleration) * delta_mult
+            if abs(vf) > dc:
+                vf -= math.copysign(dc, vf)
+            else:
+                vf = 0
+            self.yvelocity = vf
+            self.move_y(((vi + vf) / 2) * delta_mult)
 
     def event_collision(self, other, xdirection, ydirection):
         """
