@@ -1,5 +1,5 @@
 # The SGE Specification
-# Written in 2012, 2013, 2014 by Julian Marchant <onpon4@riseup.net> 
+# Written in 2012, 2013, 2014, 2015 by Julian Marchant <onpon4@riseup.net> 
 # 
 # To the extent possible under law, the author(s) have dedicated all
 # copyright and related and neighboring rights to this software to the
@@ -36,10 +36,11 @@ class Sprite(object):
 
        .. note::
 
-          Changing this attribute is a destructive transformation: it
-          can result in loss of pixel information, especially if it is
-          done repeatedly.  Because of this, it is advised that you do
-          not adjust this value for routine scaling.  Use the
+          Changing this attribute will cause the sprite to be scaled
+          horizontally.  This is a destructive transformation: it can
+          result in loss of pixel information, especially if it is done
+          repeatedly.  Because of this, it is advised that you do not
+          adjust this value for routine scaling.  Use the
           :attr:`image_xscale` attribute of a :class:`sge.Object`
           object instead.
 
@@ -49,10 +50,11 @@ class Sprite(object):
 
        .. note::
 
-          Changing this attribute is a destructive transformation: it
-          can result in loss of pixel information, especially if it is
-          done repeatedly.  Because of this, it is advised that you do
-          not adjust this value for routine scaling.  Use the
+          Changing this attribute will cause the sprite to be scaled
+          vertically.  This is a destructive transformation: it can
+          result in loss of pixel information, especially if it is done
+          repeatedly.  Because of this, it is advised that you do not
+          adjust this value for routine scaling.  Use the
           :attr:`image_yscale` attribute of a :class:`sge.Object`
           object instead.
 
@@ -364,8 +366,8 @@ class Sprite(object):
         # TODO
 
     def draw_text(self, font, text, x, y, width=None, height=None,
-                  color=sge.Color("black"), halign=sge.ALIGN_LEFT,
-                  valign=sge.ALIGN_TOP, anti_alias=True, frame=None):
+                  color=sge.Color("black"), halign="left", valign="top",
+                  anti_alias=True, frame=None):
         """
         Draw text on the sprite.
 
@@ -392,35 +394,35 @@ class Sprite(object):
           horizontal location of the origin of the imaginary rectangle
           the text is drawn in.  Can be set to one of the following:
 
-          - :data:`sge.ALIGN_LEFT` -- Align the text to the left of the
+          - ``"left"`` -- Align the text to the left of the imaginary
+            rectangle the text is drawn in.  Set the origin of the
+            imaginary rectangle to its left edge.
+          - ``"center"`` -- Align the text to the center of the
             imaginary rectangle the text is drawn in.  Set the origin of
-            the imaginary rectangle to its left edge.
-          - :data:`sge.ALIGN_CENTER` -- Align the text to the center of
-            the imaginary rectangle the text is drawn in.  Set the
-            origin of the imaginary rectangle to its center.
-          - :data:`sge.ALIGN_RIGHT` -- Align the text to the right of
-            the imaginary rectangle the text is drawn in.  Set the
-            origin of the imaginary rectangle to its right edge.
+            the imaginary rectangle to its center.
+          - ``"right"`` -- Align the text to the right of the imaginary
+            rectangle the text is drawn in.  Set the origin of the
+            imaginary rectangle to its right edge.
 
         - ``valign`` -- The vertical alignment of the text and the
           vertical location of the origin of the imaginary rectangle the
           text is drawn in.  Can be set to one of the following:
 
-          - :data:`sge.ALIGN_TOP` -- Align the text to the top of the
+          - ``"top"`` -- Align the text to the top of the imaginary
+            rectangle the text is drawn in.  Set the origin of the
+            imaginary rectangle to its top edge.  If the imaginary
+            rectangle is not tall enough to contain all of the text, cut
+            text off from the bottom.
+          - ``"middle"`` -- Align the the text to the middle of the
+            imaginary rectangle the text is drawn in.  Set the origin of
+            the imaginary rectangle to its middle.  If the imaginary
+            rectangle is not tall enough to contain all of the text, cut
+            text off equally from the top and bottom.
+          - ``"bottom"`` -- Align the text  to the bottom of the
             imaginary rectangle the text is drawn in.  Set the origin of
             the imaginary rectangle to its top edge.  If the imaginary
             rectangle is not tall enough to contain all of the text, cut
-            text off from the bottom.
-          - :data:`sge.ALIGN_MIDDLE` -- Align the the text to the middle
-            of the imaginary rectangle the text is drawn in.  Set the
-            origin of the imaginary rectangle to its middle.  If the
-            imaginary rectangle is not tall enough to contain all of the
-            text, cut text off equally from the top and bottom.
-          - :data:`sge.ALIGN_BOTTOM` -- Align the text  to the bottom of
-            the imaginary rectangle the text is drawn in.  Set the
-            origin of the imaginary rectangle to its top edge.  If the
-            imaginary rectangle is not tall enough to contain all of the
-            text, cut text off from the top.
+            text off from the top.
 
         - ``anti_alias`` -- Whether or not anti-aliasing should be used.
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
@@ -493,6 +495,54 @@ class Sprite(object):
         """
         # TODO
 
+    def mirror(self):
+        """Mirror the sprite horizontally."""
+        # TODO
+
+    def flip(self):
+        """Flip the sprite vertically."""
+        # TODO
+
+    def rotate(self, x, adaptive_resize=True):
+        """
+        Rotate the sprite about the center.
+
+        Arguments:
+
+        - ``x`` -- The rotation amount in degrees, with rotation in a
+          positive direction being counter-clockwise.
+        - ``adaptive_resize`` -- Whether or not the sprite should be
+          resized to accomodate rotation.  If this is :const:`True`,
+          rotation amounts other than multiples of 180 will result in
+          the size of the sprite being adapted to fit the whole rotated
+          image.  The origin will also be adjusted so that the rotation
+          is about the center.
+
+        .. note::
+
+           This is a destructive transformation: it can result in loss
+           of pixel information, especially if it is done repeatedly.
+           Because of this, it is advised that you do not adjust this
+           value for routine rotation.  Use the :attr:`image_rotation`
+           attribute of a :class:`sge.Object` object instead.
+        """
+        # TODO
+
+    def copy(self):
+        """Return a copy of the sprite."""
+        new_copy = Sprite(width=self.width, height=self.height,
+                          transparent=self.transparent, origin_x=self.origin_x,
+                          origin_y=self.origin_y, fps=self.fps,
+                          bbox_x=self.bbox_x, bbox_y=self.bbox_y,
+                          bbox_width=self.bbox_width,
+                          bbox_height=self.bbox_height)
+        for i in range(1, self.frames):
+            new_copy.append_frame()
+        for i in range(self.frames):
+            new_copy.draw_sprite(self, i, self.origin_x, self.origin_y, i)
+
+        return new_copy
+
     def save(self, fname):
         """
         Save the sprite to an image file.
@@ -509,6 +559,25 @@ class Sprite(object):
         """
         # TODO
 
+    @classmethod
+    def from_text(cls, font, text, width=None, height=None,
+                  color=sge.Color("black"), halign="left", valign="top",
+                  anti_alias=True):
+        """
+        Create a sprite, draw the given text on it, and return the
+        sprite.  See the documentation for :meth:`sge.Sprite.draw_text`
+        for more information.
+
+        The sprite's origin is set based on ``halign`` and ``valign``.
+        """
+        w = font.get_width(text, width, height)
+        h = font.get_height(text, width, height)
+        x = {"left": 0, "right": w, "center": w / 2}.get(halign.lower(), 0)
+        y = {"top": 0, "bottom": h, "middle": h / 2}.get(valign.lower(), 0)
+        s = cls(width=w, height=h, origin_x=x, origin_y=y)
+        s.draw_text(font, text, x, y, width, height, color, halign, valign)
+        return s
+
     @classmethod
     def from_tileset(cls, fname, x=0, y=0, columns=1, rows=1, xsep=0, ysep=0,
                      width=1, height=1, origin_x=0, origin_y=0,
@@ -565,3 +634,9 @@ class Sprite(object):
             sge.Sprite.from_screenshot().save("foo.png")
         """
         # TODO
+
+    def __copy__(self):
+        return self.copy()
+
+    def __deepcopy__(self, memo):
+        return self.copy()
